import 'package:flutter/material.dart';
import '../models/product.dart';
import '../services/database_helper.dart';

class AddEditProductScreen extends StatefulWidget {
  final Product? product;

  const AddEditProductScreen({super.key, this.product});

  @override
  State<AddEditProductScreen> createState() => _AddEditProductScreenState();
}

class _AddEditProductScreenState extends State<AddEditProductScreen> {
  final _formKey = GlobalKey<FormState>();
  late TextEditingController _nameController;
  late TextEditingController _codeController;
  late TextEditingController _quantityController;
  late TextEditingController _priceController;
  late TextEditingController _descriptionController;
  late DatabaseHelper _databaseHelper;

  bool get isEditing => widget.product != null;

  @override
  void initState() {
    super.initState();
    _databaseHelper = DatabaseHelper();
    _nameController = TextEditingController(text: widget.product?.name);
    _codeController = TextEditingController(text: widget.product?.code);
    _quantityController = TextEditingController(
      text: widget.product?.quantity.toString(),
    );
    _priceController = TextEditingController(
      text: widget.product?.price.toString(),
    );
    _descriptionController = TextEditingController(
      text: widget.product?.description,
    );
  }

  @override
  void dispose() {
    _nameController.dispose();
    _codeController.dispose();
    _quantityController.dispose();
    _priceController.dispose();
    _descriptionController.dispose();
    super.dispose();
  }

  Future<void> _saveProduct() async {
    if (_formKey.currentState!.validate()) {
      _formKey.currentState!.save();

      final product = Product(
        id: isEditing ? widget.product!.id : null,
        name: _nameController.text,
        code: _codeController.text,
        quantity: int.parse(_quantityController.text),
        price: double.parse(_priceController.text),
        description:
            _descriptionController.text.isEmpty
                ? null
                : _descriptionController.text,
      );

      if (isEditing) {
        await _databaseHelper.updateProduct(product);
      } else {
        await _databaseHelper.insertProduct(product);
      }

      if (!mounted) return;
      Navigator.pop(context, true);
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(isEditing ? 'ویرایش کالا' : 'افزودن کالا'),
        centerTitle: true,
      ),
      body: Padding(
        padding: const EdgeInsets.all(16.0),
        child: Form(
          key: _formKey,
          child: ListView(
            children: [
              TextFormField(
                controller: _nameController,
                decoration: const InputDecoration(labelText: 'نام کالا'),
                validator: (value) {
                  if (value == null || value.isEmpty) {
                    return 'لطفا نام کالا را وارد کنید';
                  }
                  return null;
                },
              ),
              const SizedBox(height: 10),
              TextFormField(
                controller: _codeController,
                decoration: const InputDecoration(labelText: 'کد کالا'),
                validator: (value) {
                  if (value == null || value.isEmpty) {
                    return 'لطفا کد کالا را وارد کنید';
                  }
                  return null;
                },
              ),
              const SizedBox(height: 10),
              TextFormField(
                controller: _quantityController,
                decoration: const InputDecoration(labelText: 'تعداد'),
                keyboardType: TextInputType.number,
                validator: (value) {
                  if (value == null || value.isEmpty) {
                    return 'لطفا تعداد را وارد کنید';
                  }
                  if (int.tryParse(value) == null) {
                    return 'تعداد باید عدد باشد';
                  }
                  return null;
                },
              ),
              const SizedBox(height: 10),
              TextFormField(
                controller: _priceController,
                decoration: const InputDecoration(labelText: 'قیمت'),
                keyboardType: TextInputType.number,
                validator: (value) {
                  if (value == null || value.isEmpty) {
                    return 'لطفا قیمت را وارد کنید';
                  }
                  if (double.tryParse(value) == null) {
                    return 'قیمت باید عدد باشد';
                  }
                  return null;
                },
              ),
              const SizedBox(height: 10),
              TextFormField(
                controller: _descriptionController,
                decoration: const InputDecoration(
                  labelText: 'توضیحات (اختیاری)',
                ),
                maxLines: 3,
              ),
              const SizedBox(height: 20),
              ElevatedButton(
                onPressed: _saveProduct,
                child: Text(isEditing ? 'ذخیره تغییرات' : 'افزودن کالا'),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
